@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -154,6 +154,7 @@ public class CurrencyNames_mr extends OpenListResourceBundle {
             { "MNT", "MNT" },
             { "MOP", "MOP" },
             { "MRO", "MRO" },
+            { "MRU", "MRU" },
             { "MUR", "MUR" },
             { "MVR", "MVR" },
             { "MWK", "MWK" },
@@ -206,6 +207,7 @@ public class CurrencyNames_mr extends OpenListResourceBundle {
             { "UYU", "UYU" },
             { "UZS", "UZS" },
             { "VEF", "VEF" },
+            { "VES", "VES" },
             { "VUV", "VUV" },
             { "WST", "WST" },
             { "YER", "YER" },
@@ -361,7 +363,8 @@ public class CurrencyNames_mr extends OpenListResourceBundle {
             { "usd", "\u092f\u0942\u090f\u0938 \u0921\u0949\u0932\u0930" },
             { "uyu", "\u0909\u0930\u0941\u0917\u094d\u0935\u0947\u091a\u093e \u092a\u0947\u0938\u094b" },
             { "uzs", "\u0909\u091d\u092c\u0947\u0915\u093f\u0938\u094d\u0924\u093e\u0928\u0940 \u0938\u094b\u092e" },
-            { "vef", "\u0935\u094d\u0939\u0947\u0928\u0947\u091d\u0941\u090f\u0932\u093e \u092c\u094b\u0932\u093f\u0935\u094d\u0939\u093e\u0930" },
+            { "vef", "\u0935\u094d\u0939\u0947\u0928\u0947\u091d\u0941\u090f\u0932\u093e \u092c\u094b\u0932\u093f\u0935\u094d\u0939\u093e\u0930 (2008\u20132018)" },
+            { "ves", "\u0935\u094d\u0939\u0947\u0928\u0947\u091d\u0941\u090f\u0932\u093e \u092c\u094b\u0932\u093f\u0935\u094d\u0939\u093e\u0930" },
             { "vnd", "\u0935\u094d\u0939\u093f\u090f\u0924\u0928\u093e\u092e\u0940 \u0921\u094b\u0902\u0917" },
             { "vuv", "\u0935\u093e\u0928\u0941\u0906\u0924\u0941 \u0935\u093e\u091f\u0941" },
             { "wst", "\u0938\u093e\u092e\u094b\u0905\u0928 \u091f\u093e\u0932\u093e" },
